@@ -26,19 +26,26 @@
 # include <sstream>
 # include <string>
 # include <stdexcept>
+# include <vector>
 
 # include "base_io.hpp"
 
 class pop3 : public base_io {
     public:
-    pop3 (const std::string&, const std::string&, const std::string&);
+    pop3 (const std::string&, const std::string&, const std::string&, bool);
     virtual ~pop3 ();
 
     virtual int start ();
 
     private:
-    virtual int recieve (bool);
+    virtual int recieve (int);
     virtual int procedure_string (std::string);
+	virtual void find_unred_mails(std::string);
+	virtual bool get_header (std::string&, unsigned);
+	virtual void set_unred(int);
+
+	std::vector<std::string> unred_mails;
+	std::stringstream line;
 };
 
 # endif
